From 5dbf2973bfb8487e852c2f675a30e3ad52e456a0 Mon Sep 17 00:00:00 2001
From: Bryce Larson <brycel@vmware.com>
Date: Thu, 21 Jan 2021 22:44:46 +0000
Subject: [PATCH] move everything to point at saltproject.io urls

---
 AUTHORS.rst        |  2 +-
 CONTRIBUTING.md    |  2 +-
 LICENSE            |  2 +-
 README.rst         | 64 +++++++++++++++++++++++-----------------------
 bootstrap-salt.ps1 |  6 ++---
 bootstrap-salt.sh  | 24 ++++++++---------
 6 files changed, 50 insertions(+), 50 deletions(-)

diff --git a/AUTHORS.rst b/AUTHORS.rst
index c9c70bb..365e122 100644
--- a/AUTHORS.rst
+++ b/AUTHORS.rst
@@ -30,7 +30,7 @@ Brandon Clifford            brandon099             brandon.clifford@vivint.com
 Bret Fisher                 BretFisher             bret@fishbrains.com
 Brian Kruger                bkruger99              brian.kruger@elliemae.com
 bruce-one                   bruce-one
-Bryce Larson                bryceml                blarson@saltstack.com
+Bryce Larson                bryceml                brycel@vmware.com
 C. R. Oldham                cro                    cr@saltstack.com
 Cam                         camereonsparr
 Charles McLaughlin          cmclaughlin
diff --git a/CONTRIBUTING.md b/CONTRIBUTING.md
index 0ee7b0a..259448d 100644
--- a/CONTRIBUTING.md
+++ b/CONTRIBUTING.md
@@ -166,7 +166,7 @@ The release process consists of the following steps:
 1. Update the version number in the bootstrap script. The version number is date-based, `<year.month.day>`.
    For example, version `2018.08.15` was released on August 15, 2018.
 1. Merge the `develop` branch into the `stable` branch.
-1. Update `bootstrap.saltstack.com` with the new stable release. The checksum on the
+1. Update `bootstrap.saltproject.io` with the new stable release. The checksum on the
    [README page](https://github.com/saltstack/salt-bootstrap/blob/develop/README.rst)
    should also be updated.
 1. Merge the new stable release into [Salt](https://github.com/saltstack/salt).
diff --git a/LICENSE b/LICENSE
index 31ccb14..1dd656b 100644
--- a/LICENSE
+++ b/LICENSE
@@ -1,6 +1,6 @@
    Salt Bootstrap - Generic Salt Bootstrap Script
 
-   Copyright 2012-2019 SaltStack (saltstack.com)
+   Copyright 2012-2021 SaltStack (saltproject.io)
 
    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
diff --git a/README.rst b/README.rst
index be62e57..10ea386 100644
--- a/README.rst
+++ b/README.rst
@@ -56,8 +56,8 @@ If you're looking for a *one-liner* to install Salt, please scroll to the bottom
 instructions for `Installing via an Insecure One-Liner`_.
 
 There are also .sha256 files for verifying against in the repo for the stable branch.  You can also
-get the correct sha256 sum for the stable release from https://bootstrap.saltstack.com/sha256 and
-https://winbootstrap.saltstack.com/sha256
+get the correct sha256 sum for the stable release from https://bootstrap.saltproject.io/sha256 and
+https://winbootstrap.saltproject.io/sha256
 
 Contributing
 ------------
@@ -83,9 +83,9 @@ To view the latest options and descriptions for ``salt-bootstrap``, use ``-h`` a
     - stable              Install latest stable release. This is the default
                           install type
     - stable [branch]     Install latest version on a branch. Only supported
-                          for packages available at repo.saltstack.com
+                          for packages available at repo.saltproject.io
     - stable [version]    Install a specific version. Only supported for
-                          packages available at repo.saltstack.com
+                          packages available at repo.saltproject.io
                           To pin a 3xxx minor version, specify it as 3xxx.0
     - testing             RHEL-family specific: configure EPEL testing repo
     - git                 Install from the head of the master branch
@@ -167,8 +167,8 @@ To view the latest options and descriptions for ``salt-bootstrap``, use ``-h`` a
         on the system.
     -R  Specify a custom repository URL. Assumes the custom repository URL
         points to a repository that mirrors Salt packages located at
-        repo.saltstack.com. The option passed with -R replaces the
-        "repo.saltstack.com". If -R is passed, -r is also set. Currently only
+        repo.saltproject.io. The option passed with -R replaces the
+        "repo.saltproject.io". If -R is passed, -r is also set. Currently only
         works on CentOS/RHEL and Debian based distributions.
     -J  Replace the Master config file with data passed in as a JSON string. If
         a Master config file is found, a reasonable effort will be made to save
@@ -210,35 +210,35 @@ If you want to install a package of a specific release version, from the SaltSta
 
 .. code:: console
 
-  curl -o bootstrap-salt.sh -L https://bootstrap.saltstack.com
+  curl -o bootstrap-salt.sh -L https://bootstrap.saltproject.io
   sudo sh bootstrap-salt.sh -P stable 3002.2
 
 If you want to install a specific release version, based on the Git tags:
 
 .. code:: console
 
-  curl -o bootstrap-salt.sh -L https://bootstrap.saltstack.com
+  curl -o bootstrap-salt.sh -L https://bootstrap.saltproject.io
   sudo sh bootstrap-salt.sh git v3002.2
 
 Using ``curl`` to install latest development version from GitHub:
 
 .. code:: console
 
-  curl -o bootstrap-salt.sh -L https://bootstrap.saltstack.com
+  curl -o bootstrap-salt.sh -L https://bootstrap.saltproject.io
   sudo sh bootstrap-salt.sh git master
 
 To install a specific branch from a Git fork:
 
 .. code:: console
 
-  curl -o bootstrap-salt.sh -L https://bootstrap.saltstack.com
+  curl -o bootstrap-salt.sh -L https://bootstrap.saltproject.io
   sudo sh bootstrap-salt.sh -g https://github.com/myuser/salt.git git mybranch
 
 If all you want is to install a ``salt-master`` using latest Git:
 
 .. code:: console
 
-  curl -o bootstrap-salt.sh -L https://bootstrap.saltstack.com
+  curl -o bootstrap-salt.sh -L https://bootstrap.saltproject.io
   sudo sh bootstrap-salt.sh -M -N git master
 
 If your host has Internet access only via HTTP proxy, from the SaltStack repo:
@@ -246,7 +246,7 @@ If your host has Internet access only via HTTP proxy, from the SaltStack repo:
 .. code:: console
 
   PROXY='http://user:password@myproxy.example.com:3128'
-  curl -o bootstrap-salt.sh -L -x "$PROXY" https://bootstrap.saltstack.com
+  curl -o bootstrap-salt.sh -L -x "$PROXY" https://bootstrap.saltproject.io
   sudo sh bootstrap-salt.sh -P -H "$PROXY" stable
 
 If your host has Internet access only via HTTP proxy, installing via Git:
@@ -254,7 +254,7 @@ If your host has Internet access only via HTTP proxy, installing via Git:
 .. code:: console
 
   PROXY='http://user:password@myproxy.example.com:3128'
-  curl -o bootstrap-salt.sh -L -x "$PROXY" https://bootstrap.saltstack.com
+  curl -o bootstrap-salt.sh -L -x "$PROXY" https://bootstrap.saltproject.io
   sudo sh bootstrap-salt.sh -H "$PROXY" git
 
 
@@ -265,21 +265,21 @@ Using ``wget`` to install your distribution's stable packages:
 
 .. code:: console
 
-  wget -O bootstrap-salt.sh https://bootstrap.saltstack.com
+  wget -O bootstrap-salt.sh https://bootstrap.saltproject.io
   sudo sh bootstrap-salt.sh
 
 Installing a specific version from git using ``wget``:
 
 .. code:: console
 
-  wget -O bootstrap-salt.sh https://bootstrap.saltstack.com
+  wget -O bootstrap-salt.sh https://bootstrap.saltproject.io
   sudo sh bootstrap-salt.sh git v3002.2
 
 Installing a specific version package from the SaltStack repo using ``wget``:
 
 .. code:: console
 
-  wget -O bootstrap-salt.sh https://bootstrap.saltstack.com
+  wget -O bootstrap-salt.sh https://bootstrap.saltproject.io
   sudo sh bootstrap-salt.sh -P stable 3002.2
 
 **NOTE**
@@ -295,21 +295,21 @@ If you already have Python installed, ``python 2.7``, then it's as easy as:
 
 .. code:: console
 
-  python -m urllib "https://bootstrap.saltstack.com" > bootstrap-salt.sh
+  python -m urllib "https://bootstrap.saltproject.io" > bootstrap-salt.sh
   sudo sh bootstrap-salt.sh -P stable 3002.2
 
 With python version 2, the following in-line code should always work:
 
 .. code:: console
 
-  python -c 'import urllib; print urllib.urlopen("https://bootstrap.saltstack.com").read()' > bootstrap-salt.sh
+  python -c 'import urllib; print urllib.urlopen("https://bootstrap.saltproject.io").read()' > bootstrap-salt.sh
   sudo sh bootstrap-salt.sh git master
 
 With python version 3:
 
 .. code:: console
 
-  python3 -c 'import urllib.request; print(urllib.request.urlopen("https://bootstrap.saltstack.com").read().decode("ascii"))' > bootstrap-salt.sh
+  python3 -c 'import urllib.request; print(urllib.request.urlopen("https://bootstrap.saltproject.io").read().decode("ascii"))' > bootstrap-salt.sh
   sudo sh bootstrap-salt.sh git v3002.2
 
 Install using fetch
@@ -320,7 +320,7 @@ have ``fetch`` available though:
 
 .. code:: console
 
-  fetch -o bootstrap-salt.sh https://bootstrap.saltstack.com
+  fetch -o bootstrap-salt.sh https://bootstrap.saltproject.io
   sudo sh bootstrap-salt.sh
 
 If you have any SSL issues install ``ca_root_nss``:
@@ -359,25 +359,25 @@ Installing the latest stable release of Salt (default):
 
 .. code:: console
 
-  curl -L https://bootstrap.saltstack.com | sudo sh
+  curl -L https://bootstrap.saltproject.io | sudo sh
 
 Using ``wget`` to install your distribution's stable packages:
 
 .. code:: console
 
-  wget -O - https://bootstrap.saltstack.com | sudo sh
+  wget -O - https://bootstrap.saltproject.io | sudo sh
 
 Installing a target version package of Salt from the SaltStack repo:
 
 .. code:: console
 
-  curl -L https://bootstrap.saltstack.com | sudo sh -s -- stable 3002.2
+  curl -L https://bootstrap.saltproject.io | sudo sh -s -- stable 3002.2
 
 Installing the latest master branch of Salt from git:
 
 .. code:: console
 
-  curl -L https://bootstrap.saltstack.com | sudo sh -s -- git master
+  curl -L https://bootstrap.saltproject.io | sudo sh -s -- git master
 
 
 Install on Windows
@@ -387,7 +387,7 @@ Using ``PowerShell`` to install latest stable version:
 
 .. code:: console
 
-  Invoke-WebRequest -Uri https://winbootstrap.saltstack.com -OutFile C:\Temp\bootstrap-salt.ps1
+  Invoke-WebRequest -Uri https://winbootstrap.saltproject.io -OutFile C:\Temp\bootstrap-salt.ps1
   Set-ExecutionPolicy -ExecutionPolicy Unrestricted -Scope CurrentUser
   C:\Temp\bootstrap-salt.ps1
   Set-ExecutionPolicy -ExecutionPolicy Undefined -Scope CurrentUser
@@ -397,7 +397,7 @@ Using ``cygwin`` to install latest stable version:
 
 .. code:: console
 
-  curl -o bootstrap-salt.ps1 -L https://winbootstrap.saltstack.com
+  curl -o bootstrap-salt.ps1 -L https://winbootstrap.saltproject.io
   "/cygdrive/c/WINDOWS/System32/WindowsPowerShell/v1.0/powershell.exe" -NoProfile -InputFormat None -ExecutionPolicy Bypass -Command "[System.Net.ServicePointManager]::SecurityProtocol = 3072; iex ./bootstrap-salt.ps1"
 
 
@@ -640,16 +640,16 @@ Make edits to .drone.jsonnet and then save them into the .drone.yml by doing the
 
 .. _Contributing Guidelines: https://github.com/saltstack/salt-bootstrap/blob/develop/CONTRIBUTING.md
 .. _Docker: https://www.docker.com/
-.. _`pre-accepted Minion keys`: https://docs.saltstack.com/en/latest/topics/tutorials/preseed_key.html
+.. _`pre-accepted Minion keys`: https://docs.saltproject.io/en/latest/topics/tutorials/preseed_key.html
 .. _`read the source`: https://github.com/saltstack/salt-bootstrap/blob/develop/bootstrap-salt.sh
-.. _`Salt`: https://saltstack.com/community/
+.. _`Salt`: https://saltproject.io/
 .. _`Salt's Supported Operating Systems`: http://get.saltstack.com/rs/304-PHQ-615/images/SaltStack-Supported-Operating-Systems.pdf
-.. _`SaltStack's corporate repository`: https://repo.saltstack.com/
-.. _`SaltStack's Debian repository`: http://repo.saltstack.com/#debian
-.. _`SaltStack's Ubuntu repository`: http://repo.saltstack.com/#ubuntu
+.. _`SaltStack's corporate repository`: https://repo.saltproject.io/
+.. _`SaltStack's Debian repository`: http://repo.saltproject.io/#debian
+.. _`SaltStack's Ubuntu repository`: http://repo.saltproject.io/#ubuntu
 .. _`Ubuntu's release schedule`: https://wiki.ubuntu.com/Releases
 .. _Vagrant: http://www.vagrantup.com
-.. _hardening salt: https://docs.saltstack.com/en/latest/topics/hardening.html
+.. _hardening salt: https://docs.saltproject.io/en/latest/topics/hardening.html
 
 .. |build|  image:: https://github.com/saltstack/salt-bootstrap/workflows/Testing/badge.svg?branch=develop
     :target: https://github.com/saltstack/salt-bootstrap/actions?query=branch%3Adevelop
diff --git a/bootstrap-salt.ps1 b/bootstrap-salt.ps1
index ffd3912..826b701 100644
--- a/bootstrap-salt.ps1
+++ b/bootstrap-salt.ps1
@@ -57,7 +57,7 @@
     Name or IP of the master server. Installer defaults to "salt".
 
 .PARAMETER repourl
-    URL to the windows packages. Default is "https://repo.saltstack.com/windows"
+    URL to the windows packages. Default is "https://repo.saltproject.io/windows"
 
 .NOTES
     All of the parameters are optional. The default should be the latest
@@ -67,7 +67,7 @@
     Bootstrap GitHub Project (script home) - https://github.com/saltstack/salt-windows-bootstrap
     Original Vagrant Provisioner Project -https://github.com/saltstack/salty-vagrant
     Vagrant Project (utilizes this script) - https://github.com/mitchellh/vagrant
-    SaltStack Download Location - https://repo.saltstack.com/windows/
+    SaltStack Download Location - https://repo.saltproject.io/windows/
 #>
 
 #===============================================================================
@@ -98,7 +98,7 @@ Param(
     [string]$master = "not-specified",
 
     [Parameter(Mandatory=$false,ValueFromPipeline=$true)]
-    [string]$repourl= "https://repo.saltstack.com/windows"
+    [string]$repourl= "https://repo.saltproject.io/windows"
 )
 
 # Powershell supports only TLS 1.0 by default. Add support for TLS 1.2
diff --git a/bootstrap-salt.sh b/bootstrap-salt.sh
index 93da5ea..64349d0 100644
--- a/bootstrap-salt.sh
+++ b/bootstrap-salt.sh
@@ -14,11 +14,11 @@
 #
 #          BUGS: https://github.com/saltstack/salt-bootstrap/issues
 #
-#     COPYRIGHT: (c) 2012-2018 by the SaltStack Team, see AUTHORS.rst for more
+#     COPYRIGHT: (c) 2012-2021 by the SaltStack Team, see AUTHORS.rst for more
 #                details.
 #
 #       LICENSE: Apache 2.0
-#  ORGANIZATION: SaltStack (saltstack.com)
+#  ORGANIZATION: SaltStack (saltproject.io)
 #       CREATED: 10/15/2012 09:49:37 PM WEST
 #======================================================================================================================
 set -o nounset                              # Treat unset variables as an error
@@ -267,7 +267,7 @@ _CUSTOM_REPO_URL="null"
 _CUSTOM_MASTER_CONFIG="null"
 _CUSTOM_MINION_CONFIG="null"
 _QUIET_GIT_INSTALLATION=$BS_FALSE
-_REPO_URL="repo.saltstack.com"
+_REPO_URL="repo.saltproject.io"
 _PY_EXE=""
 _INSTALL_PY="$BS_FALSE"
 _TORNADO_MAX_PY3_VERSION="5.0"
@@ -293,9 +293,9 @@ __usage() {
     - stable              Install latest stable release. This is the default
                           install type
     - stable [branch]     Install latest version on a branch. Only supported
-                          for packages available at repo.saltstack.com
+                          for packages available at repo.saltproject.io
     - stable [version]    Install a specific version. Only supported for
-                          packages available at repo.saltstack.com
+                          packages available at repo.saltproject.io
                           To pin a 3xxx minor version, specify it as 3xxx.0
     - testing             RHEL-family specific: configure EPEL testing repo
     - git                 Install from the head of the master branch
@@ -377,8 +377,8 @@ __usage() {
         on the system.
     -R  Specify a custom repository URL. Assumes the custom repository URL
         points to a repository that mirrors Salt packages located at
-        repo.saltstack.com. The option passed with -R replaces the
-        "repo.saltstack.com". If -R is passed, -r is also set. Currently only
+        repo.saltproject.io. The option passed with -R replaces the
+        "repo.saltproject.io". If -R is passed, -r is also set. Currently only
         works on CentOS/RHEL and Debian based distributions.
     -J  Replace the Master config file with data passed in as a JSON string. If
         a Master config file is found, a reasonable effort will be made to save
@@ -721,7 +721,7 @@ if [ "$ITYPE" != "git" ]; then
     fi
 fi
 
 # Set the _REPO_URL value based on if -R was passed or not. Defaults to repo.saltstack.com.
 if [ "$_CUSTOM_REPO_URL" != "null" ]; then
     _REPO_URL="$_CUSTOM_REPO_URL"
 
@@ -3345,9 +3345,9 @@ install_ubuntu_check_services() {
 #
 __install_saltstack_debian_repository() {
     if [ "$DISTRO_MAJOR_VERSION" -eq 11 ]; then
         # Packages for Debian 11 at repo.saltstack.com are not yet available
         # Set up repository for Debian 10 for Debian 11 for now until support
         # is available at repo.saltstack.com for Debian 11.
         echowarn "Debian 11 distribution detected, but stable packages requested. Trying packages from Debian 10. You may experience problems."
         DEBIAN_RELEASE="10"
         DEBIAN_CODENAME="buster"
@@ -6320,7 +6320,7 @@ __set_suse_pkg_repo() {
         suse_pkg_url_base="https://download.opensuse.org/repositories/systemsmanagement:/saltstack"
         suse_pkg_url_path="${DISTRO_REPO}/systemsmanagement:saltstack.repo"
     else
-        suse_pkg_url_base="${HTTP_VAL}://repo.saltstack.com/opensuse"
+        suse_pkg_url_base="${HTTP_VAL}://repo.saltproject.io/opensuse"
         suse_pkg_url_path="${DISTRO_REPO}/systemsmanagement:saltstack:products.repo"
     fi
     SUSE_PKG_URL="$suse_pkg_url_base/$suse_pkg_url_path"
@@ -7452,7 +7452,7 @@ __macosx_get_packagesite() {
     fi
 
     PKG="salt-${STABLE_REV}-${__PY_VERSION_REPO}-${DARWIN_ARCH}.pkg"
-    SALTPKGCONFURL="https://repo.saltstack.com/osx/${PKG}"
+    SALTPKGCONFURL="https://repo.saltproject.io/osx/${PKG}"
 }
 
 # Using a separate conf step to head for idempotent install...
@@ -721,7 +721,7 @@ if [ "$ITYPE" != "git" ]; then
 fi
 
-# Set the _REPO_URL value based on if -R was passed or not. Defaults to repo.saltstack.com.
+# Set the _REPO_URL value based on if -R was passed or not. Defaults to repo.saltproject.io.
 if [ "$_CUSTOM_REPO_URL" != "null" ]; then
     _REPO_URL="$_CUSTOM_REPO_URL"
@@ -3345,9 +3345,9 @@ install_ubuntu_check_services() {
 __install_saltstack_debian_repository() {
     if [ "$DISTRO_MAJOR_VERSION" -eq 11 ]; then
-        # Packages for Debian 11 at repo.saltstack.com are not yet available
+        # Packages for Debian 11 at repo.saltproject.io are not yet available
         # Set up repository for Debian 10 for Debian 11 for now until support
@@ -3345,9 +3345,9 @@ install_ubuntu_check_services() {
         # Set up repository for Debian 10 for Debian 11 for now until support
-        # is available at repo.saltstack.com for Debian 11.
+        # is available at repo.saltproject.io for Debian 11.
         echowarn "Debian 11 distribution detected, but stable packages requested. Trying packages from Debian 10. You may experience problems."
         DEBIAN_RELEASE="10"